Learn R Programming

perfectphyloR (version 0.2.1)

RandIndex: Rand Index

Description

This function calculates the Rand index, a measure of similarity between two partitions and returns a value between 0 and 1 reflecting the agreement of the partitions.

Usage

RandIndex(group1, group2)

Arguments

group1

First group.

group2

Second group.

Value

A numeric value between 0 and 1.

Examples

Run this code
# NOT RUN {
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab