Learn R Programming

perfectphyloR (version 0.2.1)

buildDend: Build the tree for the window of SNVs.

Description

This function builds the perfect phylogeny for the window of SNVs which is selected from function selectWindow.

Usage

buildDend(snvWin, sep)

Arguments

snvWin

A list contains these three components: (1) hapMat: the data structure summerizing the SNV window. (2) focalSNV: the column number of the focal SNV at which to reconstruct the perfect phylogeny. (3) compat: the local vector of whether or not each SNV in the window is compatible with the focal SNV.

sep

A character string separator for concatenating haplotype labels in the dendrogram if they are undistingushable in the window around the focal SNV , see the arguments in reconstructPP.

Value

An object of class phylo.

Details

This function works in two stages. First, it orders the SNVs in the window, based on age for compatible SNVs and proximity to the focal SNV for incompatible SNVs. Then, it makes the perfect phylogeny for the ordered SNVs using recursive partitioning and records the partitioning.

See Also

reconstructPP, orderSNVs, makeDend

Examples

Run this code
# NOT RUN {
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab