Learn R Programming

perfectphyloR (version 0.2.1)

dendToNewick: Convert a list data structure to Newick format

Description

This function traverses the dendogram to build the character string that represents the dendrogram in Newick format.

Usage

dendToNewick(dend, sep = "-")

Arguments

dend

A list of nodes that represents the nested partition of haplotypes.

sep

A separator for haplotype names in the same clade. See the arguments in reconstructPP.

Value

A character string in Newick format.

See Also

makeDend

Examples

Run this code
# NOT RUN {
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab