Learn R Programming

perfectphyloR (version 0.2.1)

findSNVs: Find the window of SNVs at a focal point

Description

This function identifies a window of compatible SNVs about the focal SNV.

Usage

findSNVs(hapMat, focalSNV, minWindow = 1)

Arguments

hapMat

hapMat data object.

focalSNV

The column number of the focal in the haplotype data matrix at which to reconstruct the dendrogram.

minWindow

Minimum window size of the SNV neighborhood.

Value

Return a list of SNVs in the window with their state of compatiblity to selectWindow.

Details

This function starts at the focal SNV, and tries expanding the neighborhood of compatible SNVs. This process is stopped when there are no more compatible SNVs to the left or right of the focal SNV. If the block of compatible SNVs does not have at least a user-defined minimum number of SNVs, this function expands the window to include incompatible SNVs.

See Also

selectWindow, checkCompatible, getnSNVs, getNextFromFocal, getNextLeftFocal, getNextRightFocal

Examples

Run this code
# NOT RUN {
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab