Learn R Programming

perfectphyloR (version 0.2.1)

getNextRightFocal: Expand the neighborhood to the right

Description

This function tries to expand the neighborhood to the right, when the next SNV from getNextFromFocal function is incompatible with each SNV in the neighborhood of the focal SNV, and this incompatible SNV could be to the left of the neighborhood.

Usage

getNextRightFocal(current, absDist)

Arguments

current

Current SNVs in the neighborhood of focal SNV.

absDist

Absolute distance of SNVs from the focal SNV in base pairs.

Value

An index of a SNV.

Examples

Run this code
# NOT RUN {
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab