Learn R Programming

perfectphyloR (version 0.2.1)

orderSNVs: Order SNVs

Description

This function orders the SNVs in the window around the SNV.

Usage

orderSNVs(snvWin)

Arguments

snvWin

See the arguments in buildDend

Value

A hapMat with ordered SNVs.

Details

Following Gusfield (1991), the first step in building the dendogram is to order compatible SNVs by their ancestry. Then, following Mailund et al. (2006) the incompatible SNVs are ordered according to their proximity to the focal SNV.

References

Gusfield, D. (1991). Efficient algorithms for inferring evolutionary trees. Networks, 21(1), 19-28.

Mailund, T., Besenbacher, S., & Schierup, M. H. (2006). Whole genome association mapping by incompatibilities and local perfect phylogenies. BMC Bioinformatics, 7(1), 454.

See Also

buildDend, orderColsAncestry

Examples

Run this code
# NOT RUN {
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab