Learn R Programming

perfectphyloR (version 0.2.1)

perfectphyloR-package: Reconstruct perfect phylogenies from DNA sequence data

Description

Functions to reconstruct perfect phylogeny underlying a sample of DNA sequences, at a focal single-nucleotide variant (SNV) and to depict and test association in a genomic region based on the reconstructed partitions.

Arguments