Learn R Programming

perfectphyloR (version 0.2.1)

tdend: True dendrogram object

Description

A phylo object containing attributes of the comparator true dendrogram for the example data at SNV position 975 kilo base pairs.

Usage

data(tdend)

Arguments

Format

A phylo object from the ape package containing four attributes:

edge

A matrix containing the node labels and their child nodes.

Nnode

The number of nodes.

tip.label

A character vector containing the haplotype labels of the true dendrogram.

edge.length

A numeric vector giving the lengths of the branches given by edge.