powered by
This function calculates the Rand index, a measure of similarity between two partitions and returns a value between 0 and 1 reflecting the agreement of the partitions.
RandIndex(group1, group2)
First group.
Second group.
A numeric value between 0 and 1.
# NOT RUN { # } # NOT RUN { # }
Run the code above in your browser using DataLab