powered by
This function traverses the dendogram to build the character string that represents the dendrogram in Newick format.
dendToNewick(dend, sep = "-")
A list of nodes that represents the nested partition of haplotypes.
A separator for haplotype names in the same clade. See the arguments in reconstructPP.
reconstructPP
A character string in Newick format.
makeDend
# NOT RUN { # } # NOT RUN { # }
Run the code above in your browser using DataLab