extractHaplos: Extract haplotypes and return it as a list from genotype matrix by vcf file.
Description
Extract haplotypes and return it as a list from genotype matrix by vcf file.
Usage
extractHaplos(vcfGeno, snvPosns)
Arguments
vcfGeno
genotype matrix extract from vcf file.
snvPosns
SNV positions in base paris.
Value
a list of haplotype data with positions