orderColsAncestry: Utility function needed by orderSNVs
Description
This function orders the compatible SNVs in the window around the focal point by their ancestry.
Usage
orderColsAncestry(M)
Arguments
M
hapMat object with compatible SNVs.
Value
A hapMat object with SNVs ordered according to their ancestry.
Details
This function sorts columns of M as binary numbers in descending order.
The first row of M is the first digit of the binary numbers, the second row of M is the second digit, etc.
This guarantees that more ancestral SNVs appear before more recent SNVs.